@@ -1,10 +1,12 @@
 module Def (S : Cstubs.Types.TYPE) = struct
+  include Posix_eai_errno_constants.Def (S)
+
   let af_inet = S.constant "AF_INET" S.int
   let af_inet6 = S.constant "AF_INET6" S.int
   let af_unix = S.constant "AF_UNIX" S.int
   let af_unspec = S.constant "AF_UNSPEC" S.int
-  let sa_data_len = S.constant "SA_DATA_LEN" S.int
   let sa_family_t_len = S.constant "SA_FAMILY_T_LEN" S.int
+  let sockaddr_storage_len = S.constant "SOCKADDR_STORAGE_LEN" S.int
   let sock_dgram = S.constant "SOCK_DGRAM" S.int
   let sock_stream = S.constant "SOCK_STREAM" S.int
   let sock_seqpacket = S.constant "SOCK_STREAM" S.int
